# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""remote carta correction

Revision ID: ba9045f98c5f
Revises: d8f7f2fe2ae9
Create Date: 2021-09-20 16:50:30.850788

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "ba9045f98c5f"
down_revision = "d8f7f2fe2ae9"
branch_labels = None
depends_on = None

script_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR
{{#remote-cv}}
export CAPO_PATH=$(readlink -f $TMPDIR)
export CAPO_PROFILE={{profile}}
{{/remote-cv}}
fetch_foundation(){
  ../productfetcher{{product_locator}}

  echo "Moving images out of subdirectories...."
  for dir in *.fits; do mv $dir $dir.1; done;

  find . -mindepth 1 -type f -print -exec mv {} . \;
  find . -mindepth 1 -type d -empty -delete
  echo "Done. Ready for Carta!"
}


{{#need_data}}
./framework.sh -r .
chmod 770 .
cd rawdata/

fetch_foundation {{^single_image}}&{{/single_image}}

.{{/need_data}}./carta_envoy {{#need_data}}--parallel{{/need_data}} {{#single_image}}--single -i {{imageName}}{{/single_image}} -d $1 -n $2 -wf $3 -r $4
{{#need_data}}wait{{/need_data}}
"""

condor_content = """executable = carta.sh
arguments = {{source_dir}} {{user_email}} {{request_id}} {{notify_ready}}

output = carta.out
error = carta.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/carta_envoy{{#remote-cv}}, {{profile}}.properties{{/remote-cv}}
{{#need_data}}transfer_output_files = rawdata{{/need_data}}

request_memory = {{ramInGb}}
getenv = True
{{^remote-cv}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote-cv}}
{{#remote-cv}}
requirements = HasLustre == True && (CVPOST == True)
+partition = "CVPOST"
{{/remote-cv}}

queue
"""

old_script = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

fetch_foundation(){
  ../productfetcher{{product_locator}}

  echo "Moving images out of subdirectories...."
  for dir in *.fits; do mv $dir $dir.1; done;

  find . -mindepth 1 -type f -print -exec mv {} . \;
  find . -mindepth 1 -type d -empty -delete
  echo "Done. Ready for Carta!"
}


{{#need_data}}
./framework.sh -r .
chmod 770 .
cd rawdata/

fetch_foundation {{^single_image}}&{{/single_image}}

.{{/need_data}}./carta_envoy {{#need_data}}--parallel{{/need_data}} {{#single_image}}--single -i {{imageName}}{{/single_image}} -d $1 -n $2 -wf $3 -r $4
{{#need_data}}wait{{/need_data}}

"""

old_condor = """executable = carta.sh
arguments = {{source_dir}} {{user_email}} {{request_id}} {{notify_ready}}

output = carta.out
error = carta.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/carta_url_template.html, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/carta_envoy{{#remote-cv}}, {{profile}}.properties{{/remote-cv}}
{{#need_data}}transfer_output_files = rawdata{{/need_data}}

request_memory = {{ramInGb}}
getenv = True
{{^remote-cv}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote-cv}}
{{#remote-cv}}
environment = "CAPO_PATH=. CAPO_PROFILE={{profile}}"

requirements = HasLustre == True && (CVPOST == True)
+partition = "CVPOST"
{{/remote-cv}}

queue

"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{script_content}' WHERE filename='carta.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{condor_content}' WHERE filename='carta.condor'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_script}' WHERE filename='carta.sh'
        """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{old_condor}' WHERE filename='carta.condor'
            """
    )
